import Enzyme from "enzyme";
import React from "react";

import { Delete } from "../../../elements";
import { ModalCardHead } from "../modal-card-head";

import {
  hasProperties,
  shallowInContext,
  testGenericPropTypes,
} from "../../../__tests__/testing";
import { contextFactory } from "./context";

describe("ModalCardHead component", () => {
  hasProperties(ModalCardHead, {
    defaultProps: { as: "header" },
  });

  it("should render as the default element", () => {
    const wrapper = shallowInContext(ModalCardHead, contextFactory(), {});
    expect(wrapper.is("header")).toBe(true);
  });

  it("should render as a custom component", () => {
    const as = "span";
    const wrapper = shallowInContext(ModalCardHead, contextFactory(), { as });
    expect(wrapper.is(as)).toBe(true);
  });

  it("should forward ref", () => {
    const ref = React.createRef<HTMLElement>();
    // Enzyme owns outer ref: https://github.com/airbnb/enzyme/issues/1852
    const wrapper = Enzyme.mount(
      <div>
        <ModalCardHead ref={ref} />
      </div>,
    );
    try {
      expect(ref.current).toBe(wrapper.find(".modal-card-head").instance());
    } finally {
      wrapper.unmount();
    }
  });

  it("should have bulma className", () => {
    const wrapper = shallowInContext(ModalCardHead, contextFactory(), {});
    expect(wrapper.hasClass("modal-card-head")).toBe(true);
  });

  it("should preserve custom className", () => {
    const className = "foo";
    const wrapper = shallowInContext(ModalCardHead, contextFactory(), {
      className,
    });
    expect(wrapper.hasClass(className)).toBe(true);
  });

  [false, true].map(hasOnClick =>
    it(`should call the context"s onClose ${
      hasOnClick ? "and Delete's onClick" : ""
    }`, () => {
      const onClick = jest.fn();
      const onClose = jest.fn();
      const wrapper = shallowInContext(
        ModalCardHead,
        contextFactory({ onClose }),
        { children: <Delete onClick={hasOnClick ? onClick : undefined} /> },
      );
      wrapper.find(Delete).simulate("click");
      expect(onClose.mock.calls).toHaveLength(1);
      expect(onClick.mock.calls).toHaveLength(hasOnClick ? 1 : 0);
    }),
  );

  it("should pass through non-Delete children", () => {
    const wrapper = shallowInContext(ModalCardHead, contextFactory(), {
      children: <div id="foo" />,
    });
    expect(wrapper.children().prop("id")).toBe("foo");
  });

  describe("propTypes", () => {
    const { propTypes } = ModalCardHead;
    testGenericPropTypes(propTypes);
  });
});
